@@ -7,6 +7,7 @@ class Section:
     inner: List[Element] = []
     header_size: int = 2
     have_header: bool = True
+    space_between_elements = True
 
     def to_markdown(self):
         from ..generator import md
@@ -14,7 +15,7 @@ class Section:
         markdown_text += (md(Header(self.header_size, self.title)) + md(Br())*2) if self.have_header else ""
 
         for el in self.inner:
-            markdown_text += md(el) + md(Br())*2
+            markdown_text += md(el) + (md(Br())*2) if self.space_between_elements else ""
 
         return markdown_text
 
